@@ -27,7 +27,7 @@ package Rex::Commands::Upload;
 use strict;
 use warnings;
 
-our $VERSION = '1.3.1'; # VERSION
+our $VERSION = '1.3.2'; # VERSION
 
 require Rex::Exporter;
 use File::Basename qw(basename);
@@ -117,7 +117,9 @@ sub upload {
 
   my $old_local = $local; # for the upload location use the given name
 
-  if ( -f "$local." . Rex::Config->get_environment ) {
+  if ( Rex::Config->get_environment
+    && -f "$local." . Rex::Config->get_environment )
+  {
     $local = "$local." . Rex::Config->get_environment;
   }
 
